# musort

A music-sorting package.

## Installation

From PyPI:

```bash
python -m pip install -U musort
```

From source:

```sh
git clone https://github.com/ernieIzde8ski/mus_sort/tree/module_v2.git mus_sort
cd mus_sort
python -m pip install -e .
```

Building from source:

```bash
git clone https://github.com/ernieIzde8ski/mus_sort/tree/module_v2.git mus_sort
cd mus_sort
python -m venv venv
pip install -r requirements.txt
./build.sh
```

## Usage

See `python -m musort --help` for usage.
